/***********************************************************
*   dynaGraph.js
*   2004, Heiko Niemann
***********************************************************/
var svgDoc;
var svgRoot;

var ns = {
	svg:"http://www.w3.org/2000/svg",
	xlink:"http://www.w3.org/1999/xlink"};
	
var NbGraphs = 2;
var NbPoints = 26;
var distcPts = 15;

var isActiv = false;
var speed = {min:1,max:30,cur:0,upd:5};
var rgb = ['#d00','#00d'];

var myT = [];
var vals = {g1:[],g2:[],g3:[]};
var shft = {g1:null,g2:null,g3:null};

var myDots = {g1:[],g2:[],g3:[]};
var myLine = {g1:null,g2:null,g3:null};
var myTime = [];

var myPoly = [];

var timeOut = null;
var toolTip = true;


function init(e){
	
	svgDoc = document;
	svgRoot = document.documentElement;
			
	setToolTip(toolTip);
	
	var boxHeight = (NbPoints+1)*distcPts;
	var graphBox = [-10,distcPts/-2,200,boxHeight].join("\ ");

	setAttr('graphBox',null,'viewBox',graphBox);
	setAttr('graphBox',null,'height',boxHeight);
	setAttr('graphBG',null,'height',boxHeight+2);
	setAttr('line0',null,'y2',boxHeight);
	setAttr('line20',null,'y2',boxHeight);
	setAttr('line40',null,'y2',boxHeight);
	setAttr('line60',null,'y2',boxHeight);
	setAttr('line80',null,'y2',boxHeight);
	setAttr('line100',null,'y2',boxHeight);
	
	var str;
	var graphLines = svgDoc.getElementById('graphLines');
	var graphDots = svgDoc.getElementById('graphDots');
	var graphTime = svgDoc.getElementById('graphTime');
	
	//create line-elements
	for(var n=1;n<=NbGraphs;n++){
		var poly = svgDoc.createElementNS(ns.svg,'polyline');
		setAttr(poly,null,'fill','none');
		setAttr(poly,null,'stroke',rgb[n-1]);
		setAttr(poly,null,'stroke-width','1.2');
		setAttr(poly,null,'points','0 0');
		myLine['g'+n] =	graphLines.appendChild(poly);
	}
	
	for(m=0;m<NbPoints;m++){
		//create circle-elements
		
		for(var n=1;n<=NbGraphs;n++){
			str = '<circle xmlns="'+ns.svg+'" cx="-20" cy="'+(m*distcPts)+'" r="3" fill="'+rgb[n-1]+'"/>';
			var circ = svgDoc.createElementNS(ns.svg,'circle');
			setAttr(circ,null,'cx','-20');
			setAttr(circ,null,'cy',m*distcPts);
			setAttr(circ,null,'r','3');
			setAttr(circ,null,'fill',rgb[n-1]);
			myDots['g'+n][m] = graphDots.appendChild(circ);
			
		}
		
		var text = svgDoc.createElementNS(ns.svg,'text');
		setAttr(text,null,'x','165');
		setAttr(text,null,'y',m*distcPts+5);
		text.appendChild(svgDoc.createTextNode(''));
		myTime[m] = graphTime.appendChild(text);
	}
	
	setRequestRate('apply');
}


function requestData(){
	if(isActiv) 
		getURL('dynaGraph.php?t='+(new Date().getTime()),processData);
	else{
		//continue and reset will show when last timeout is over
		//isActiv = false;
		setAttr('resetButton',null,'fill-opacity','1');
		setAttr('startButton',null,'fill-opacity','1');
	}
}


function processData(response){
	if(response.success) 
		updateData(response.content);
	else 
		alert('data could not be loaded');
}


function updateData(newData){
	if(myT.length>=NbPoints){ 
		for(var i=1;i<=NbGraphs;i++) shft['g'+i] = vals['g'+i].shift() + ',' + (-1*distcPts)+ ' ';
		myT.shift();
	}

	eval("var retVal = " + newData);

	for(var i=1;i<=NbGraphs;i++) 
		vals['g'+i].push(retVal['g'+i]);

	myT.push(retVal.ctime);

	drawGraph();

	setTimeout('requestData()',speed.cur*1000);
}


function drawGraph(){

	for(var i=1;i<=NbGraphs;i++) myPoly[i] = (shft['g'+i])?shft['g'+i]:'';
	
	for(j=0;j<myT.length;j++){
		for(var i=1;i<=NbGraphs;i++){
			setAttr(myDots['g'+i][j],null,'cx',vals['g'+i][j]);
			myPoly[i] += vals['g'+i][j] + "," + j*distcPts + " ";
		}
		myTime[j].firstChild.data = myT[j];
	}
	
	for(var i=1;i<=NbGraphs;i++) {
		setAttr(myLine['g'+i],null,'points',myPoly[i]);
	}
}


function replaceValues(myArray,replVal){
	for(i=0;i<myArray.length;i++) 
		myArray[i] = replVal;
}


function clearArray(myArray){
	var k = myArray.length;
	for(i=0;i<k;i++) 
		myArray.shift();
}


function requestControl(myTask){
	switch (myTask){
		case "reset":	if(isActiv) break;
									setAttr('resetButton',null,'fill-opacity','.4');
									shft.g1 = "";
									shft.g2 = "";
									replaceValues(vals.g1,-100);
									replaceValues(vals.g2,-100);
									replaceValues(myT,"");
									drawGraph();
									clearArray(vals.g1);
									clearArray(vals.g2);
									clearArray(myT);
									break;
		case "play": 	if(isActiv) break;
									isActiv = true;
									setAttr('startButton',null,'fill-opacity','.4');
									setAttr('resetButton',null,'fill-opacity','.4');
									setAttr('pauseButton',null,'fill-opacity','1');
									requestData();
									break;
		case "pause": if(!isActiv) break;
									isActiv = false;
									setAttr('pauseButton',null,'fill-opacity','.4');
									//to prohibit immediate restart/reset values are set in dataRequest-function
									//setAttr('resetButton',null,'fill-opacity','1');
									//setAttr('startButton',null,'fill-opacity','1');
									//clearTimeout(myTO);
									break;
	}
}


function setRequestRate(button){
	var navSet = {dis:'inline',bt_r:'1',bt_i:'1'};;
	
	switch (button){
		case 'open':			speed.upd = speed.cur;
											break;
		case 'apply':			navSet.dis = 'none';
											speed.cur = speed.upd;
											break;
		case 'cancel':		navSet.dis = 'none';
											break;
		case 'reduce':		if(speed.upd==speed.min) 
											break;
											speed.upd--;
											break;
		case 'increase':	if(speed.upd==speed.max) 
											break;
											speed.upd++;
											break;
	}
	
	if(speed.upd<=speed.min) navSet.bt_r = '.4';
	if(speed.upd>=speed.max) navSet.bt_i = '.4';
	
	setAttr('speedNavi',null,'display',navSet.dis);
	setText('speedTxt',speed.cur);
	setText('updateTxt',speed.upd);
	setAttr('bt_r',null,'fill-opacity',navSet.bt_r);
	setAttr('bt_i',null,'fill-opacity',navSet.bt_i);
}


function graphControl(myTask){
	switch (myTask){
		case "both":	setAttr('linesButton',null,'fill','#add8e6');
									setAttr('dotsButton',null,'fill','#add8e6');
									setAttr('bothButton',null,'fill','#ccee88');
									setAttr('graphLines',null,'display','inline');
									setAttr('graphDots',null,'display','inline');
									break;
		case "lines": setAttr('bothButton',null,'fill','#add8e6');
									setAttr('dotsButton',null,'fill','#add8e6');
									setAttr('linesButton',null,'fill','#ccee88');
									setAttr('graphLines',null,'display','inline');
									setAttr('graphDots',null,'display','none');
									break;
		case "dots": 	setAttr('bothButton',null,'fill','#add8e6');
									setAttr('linesButton',null,'fill','#add8e6');
									setAttr('dotsButton',null,'fill','#ccee88');
									setAttr('graphLines',null,'display','none');
									setAttr('graphDots',null,'display','inline');
	}
}


function setAttr(elem,ns,attr,val){
	var target = (typeof elem == 'string') ? svgDoc.getElementById(elem) : elem;
	target.setAttributeNS(ns,attr,val);	
}


function setText(elem,val){
	var target = (typeof elem == 'string') ? svgDoc.getElementById(elem) : elem;
	target.firstChild.data = val;
}


/********************************************************
*					toolTips																			*
********************************************************/

function showToolTip(e){
	if(toolTip){
		var trg = e.target;
		var trn = ['translate(',e.clientX+15,',',e.clientY-25,')'].join('');
		
		if(timeOut) 
			clearTimeout(timeOut);
		
		svgDoc.getElementById('toolTipTxt').firstChild.data = trg.getAttributeNS(null,'cx') + ' %';
		svgDoc.getElementById('toolTipGrp').setAttributeNS(null,'transform',trn); 
		svgDoc.getElementById('toolTipGrp').setAttributeNS(null,'display','inline');
	}
}

function hideToolTip(){
	timeOut = setTimeout('hideToolTipExe()',500);
}	

function hideToolTipExe(){
	svgDoc.getElementById('toolTipGrp').setAttributeNS(null,'display','none');
}

function setToolTip(mode){
	toolTip = (mode!=null)?mode:!toolTip;
	svgDoc.getElementById('toolTipCheck').setAttributeNS(null,'display',toolTip?'inline':'none');
}
